==> pagedesigner-2.0.0-rc2.tar.gz: pagedesigner/modules/pagedesigner_link/src/Plugin/pagedesigner/Handler/Link.php <==
<?php

namespace Drupal\pagedesigner_link\Plugin\pagedesigner\Handler;

use Drupal\Core\Url;
use Drupal\pagedesigner\Entity\Element;
use Drupal\pagedesigner\Plugin\PlainFieldHandlerBase;
use Drupal\Core\Language\LanguageInterface;

/**
 * Process entities of type "link".
 *
 * @PagedesignerHandler(
 *   id = "link",
 *   name = @Translation("Link handler"),
 *   types = {
 *      "link",
 *      "href",
 *   },
 * )
 */
class Link extends PlainFieldHandlerBase {

  /**
   * {@inheritdoc}
   */
  public function collectAttachments(array &$attachments) {
    $attachments['library'][] = 'pagedesigner_link/pagedesigner';
  }

  /**
   * {@inheritdoc}
   */
  public function serialize(Element $entity, array &$result = []) {
    $result = [
      'uri' => $entity->field_link->uri,
      'title' => $entity->field_link->title,
    ] + $result;
  }

  /**
   * {@inheritdoc}
   */
  public function get(Element $entity, string &$result = '') {
    $result = $entity->field_link->uri;
    if (strpos($result, '/') === 0) {
      $url = Url::fromUri("internal:" . $result);
      if ($url->isRouted()) {
        $params = $url->getRouteParameters();
        $entity_type = key($params);
        if ($entity_type == 'media') {
          $mediaEntity = \Drupal::entityTypeManager()->getStorage($entity_type)->load($params[$entity_type]);
          if ($mediaEntity != NULL) {
            $url = \Drupal::service('plugin.manager.linkit.substitution')
              ->createInstance('media')
              ->getUrl($mediaEntity);
            if ($url) {
              $result = $url->getGeneratedUrl();
            }
          }
        }
        elseif ($entity_type == 'node' && isset($params['node'])) {
          $nodeInternalPath = '/node/' . $params['node'];
          $langcode = trim(str_replace($nodeInternalPath, '', $result), '/');
          if (empty($langcode)) {
            $langcode = $this->languageManager
              ->getCurrentLanguage(LanguageInterface::TYPE_CONTENT)
              ->getId();
          }
          $result = \Drupal::service('path_alias.manager')->getAliasByPath($nodeInternalPath, $langcode);
          $result = '/' . $langcode . $result;
        }
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getContent(Element $entity, array &$list = [], $published = TRUE) {

  }

  /**
   * {@inheritdoc}
   */
  public function render(Element $entity, array &$build = []) {
    $build = [];
    parent::render($entity, $build);
    if (strpos($entity->field_link->uri, '/') === 0) {
      $url = Url::fromUri("internal:" . $entity->field_link->uri);
      if ($url->isRouted()) {
        $params = $url->getRouteParameters();
        $entity_type = key($params);
        if ($entity_type == 'media') {
          $mediaEntity = \Drupal::entityTypeManager()->getStorage($entity_type)->load($params[$entity_type]);
          if ($mediaEntity != NULL) {
            \Drupal::service('renderer')->addCacheableDependency($build, $mediaEntity);
          }
        }
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function patch(Element $entity, array $data) {
    // Treat empty urls as null.
    $uri = empty($data['uri']) ? NULL : $data['uri'];
    $entity->field_link->uri = $uri;
    $entity->field_link->title = empty($data['title']) ? '' : $data['title'];
    $entity->saveEdit();
  }

  /**
   * {@inheritdoc}
   */
  public function generate($definition, array $data, Element &$entity = NULL) {
    parent::generate(['type' => 'link', 'name' => 'link'], $data, $entity);
  }

}

==> pagedesigner-2.0.2.tar.gz: pagedesigner/modules/pagedesigner_link/src/Plugin/pagedesigner/Handler/Link.php <==
<?php

namespace Drupal\pagedesigner_link\Plugin\pagedesigner\Handler;

use Drupal\Core\Url;
use Drupal\pagedesigner\Entity\Element;
use Drupal\pagedesigner\Plugin\PlainFieldHandlerBase;
use Drupal\Core\Language\LanguageInterface;

/**
 * Process entities of type "link".
 *
 * @PagedesignerHandler(
 *   id = "link",
 *   name = @Translation("Link handler"),
 *   types = {
 *      "link",
 *      "href",
 *   },
 * )
 */
class Link extends PlainFieldHandlerBase {

  /**
   * {@inheritdoc}
   */
  public function collectAttachments(array &$attachments) {
    $attachments['library'][] = 'pagedesigner_link/pagedesigner';
  }

  /**
   * {@inheritdoc}
   */
  public function serialize(Element $entity, array &$result = []) {
    $result = [
      'uri' => $entity->field_link->uri,
      'title' => $entity->field_link->title,
    ] + $result;
  }

  /**
   * {@inheritdoc}
   */
  public function get(Element $entity, string &$result = '') {
    $result = (string) $entity->field_link->uri;
    if (strpos($result, '/') === 0) {
      $url = Url::fromUri("internal:" . $result);
      if ($url->isRouted()) {
        $params = $url->getRouteParameters();
        $entity_type = key($params);
        if ($entity_type == 'media') {
          $mediaEntity = \Drupal::entityTypeManager()->getStorage($entity_type)->load($params[$entity_type]);
          if ($mediaEntity != NULL) {
            $url = \Drupal::service('plugin.manager.linkit.substitution')
              ->createInstance('media')
              ->getUrl($mediaEntity);
            if ($url) {
              $result = $url->getGeneratedUrl();
            }
          }
        }
        elseif ($entity_type == 'node' && isset($params['node'])) {
          $nodeInternalPath = '/node/' . $params['node'];
          $langcode = trim(str_replace($nodeInternalPath, '', $result), '/');
          if (empty($langcode)) {
            $langcode = $this->languageManager
              ->getCurrentLanguage(LanguageInterface::TYPE_CONTENT)
              ->getId();
          }
          $result = \Drupal::service('path_alias.manager')->getAliasByPath($nodeInternalPath, $langcode);
          $result = '/' . $langcode . $result;
        }
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getContent(Element $entity, array &$list = [], $published = TRUE) {

  }

  /**
   * {@inheritdoc}
   */
  public function render(Element $entity, array &$build = []) {
    $build = [];
    parent::render($entity, $build);
    $uri = (string) $entity->field_link->uri;
    if (strpos($uri, '/') === 0) {
      $url = Url::fromUri("internal:" . $uri);
      if ($url->isRouted()) {
        $params = $url->getRouteParameters();
        $entity_type = key($params);
        if ($entity_type == 'media') {
          $mediaEntity = \Drupal::entityTypeManager()->getStorage($entity_type)->load($params[$entity_type]);
          if ($mediaEntity != NULL) {
            \Drupal::service('renderer')->addCacheableDependency($build, $mediaEntity);
          }
        }
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function patch(Element $entity, array $data) {
    // Treat empty urls as null.
    $uri = empty($data['uri']) ? NULL : $data['uri'];
    $entity->field_link->uri = $uri;
    $entity->field_link->title = empty($data['title']) ? '' : $data['title'];
    $entity->saveEdit();
  }

  /**
   * {@inheritdoc}
   */
  public function generate($definition, array $data, Element &$entity = NULL) {
    parent::generate(['type' => 'link', 'name' => 'link'], $data, $entity);
  }

}
